@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000064-000002"; }
+sub IDENTIFICATION { return "000001-000064-000003"; }
 
 sub preference { return 2000; }
 
@@ -20,6 +20,11 @@ sub init {
         $obj->{prompt_num} = $obj->{-interface}->register_prompt(500);
 }
 
+sub done {
+	my $obj = shift;
+	$obj->{-interface}->deregister_prompt($obj->{prompt_num});
+}
+
 sub handle_action {
 	my ($obj,%action) = @_;
 
