@@ -5,12 +5,12 @@ use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 use Text::FormatTable;
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000039-000003"; }
+sub IDENTIFICATION { return "000001-000039-000004"; }
 
 sub preference { return 50; }
 
@@ -27,19 +27,22 @@ sub handle_action {
 
 		my $sth = $obj->{-dbi}->table_info( { TABLE_SCHEM => uc($obj->{-dbi}->login) } );
 		my $ret = $sth->fetchall_arrayref();
-		if (defined $ret) {
-			for (sort { $a->[2] cmp $b->[2] } @$ret) {
-				if (($action{type} eq 'object'
-				  or $action{type} eq lc $_->[3]) and
-				  $action{mask} and $_->[2] =~ /$action{mask}/i) {
-					$table->row($_->[2],$_->[3]);
+		study $action{mask};
+		eval {
+			if (defined $ret) {
+				for (sort { $a->[2] cmp $b->[2] } @$ret) {
+					if (($action{type} eq 'object'
+					  or $action{type} eq lc $_->[3]) and
+					  $action{mask} and $_->[2] =~ /$action{mask}/i) {
+						$table->row($_->[2],$_->[3]);
+					}
 				}
 			}
-		}
+		};
 		$sth->finish;
 		$table->rule;
 		$action{action} = 'OUTPUT';
-		$action{output} = $table->render($obj->{-interface}->render_size);
+		$action{output} = $@?"Invalid regular expression.\n":$table->render($obj->{-interface}->render_size);
 	}
 
 	$action{processed} = 1;
